#-*- coding:utf-8 -*-
import json
import logging
import urllib2

from celery import task
from celery.signals import beat_init
from djcelery.models import PeriodicTask, IntervalSchedule

from pingokio.domains.models import AvailabilityTestCase, CheckLog

logger = logging.getLogger(__name__)


def get(availability_test_case_id):
    return True


@task
def post(availability_test_case_id):
    return True


@task
def ping(availability_test_case_id):
    return True


@task
def process_atc(atc_pk):
    atc = AvailabilityTestCase.objects.get(pk=atc_pk)
    if atc.kind == AvailabilityTestCase.GET:
        try:
            a = urllib2.urlopen(atc.url)
            if a.code == 200:
                CheckLog(atc=atc, result='ok', status=True).save()
            else:
                CheckLog(atc=atc, result='false', status=False).save()
        except:
            CheckLog(atc=atc, result='false', status=False).save()
    logger.debug('process atc %s' % atc.pk)


def create_periodic_tasks(sender=None, **kwargs):
    logger.info("beat_init signal")
    for test in AvailabilityTestCase.objects.all():
        test_name = 'atc' + str(test.pk)
        if PeriodicTask.objects.filter(name=test_name).exists():
            PeriodicTask.objects.filter(name=test_name).delete()
        interval_schedule = IntervalSchedule(every=test.period, period='seconds')
        interval_schedule.save()
        PeriodicTask(name=test_name, task='pingokio.domains.tasks.process_atc', interval=interval_schedule, args=json.dumps([test.pk])).save()
        logger.debug('register task for %s' % test)

beat_init.connect(create_periodic_tasks)



# Django settings for pingokio project.
import os
import djcelery


DEBUG = True
TEMPLATE_DEBUG = DEBUG

PROJECT_PATH = os.path.abspath(os.path.dirname(__file__))

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(PROJECT_PATH, 'database.sqlite3'),
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
    }
}

TIME_ZONE = 'America/Chicago'
LANGUAGE_CODE = 'en-us'
SITE_ID = 1
USE_I18N = True
USE_L10N = True
USE_TZ = True

MEDIA_ROOT = os.path.join(PROJECT_PATH, 'media')
MEDIA_URL = '/media/'
STATIC_ROOT = os.path.join(PROJECT_PATH, 'static')
STATIC_URL = '/static/'

STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

SECRET_KEY = '12z&amp;-!h#*23u196s@c)fog%tgqpdz6l__(ks$pj#r)r7xo_4j7'

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'pingokio.server.urls'

WSGI_APPLICATION = 'pingokio.wsgi.application'

TEMPLATE_DIRS = (
    os.path.join(PROJECT_PATH, 'templates'),
)

PROJECT_APPS = (
    'pingokio.domains',
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',

    'djcelery',
    'djkombu',
) + PROJECT_APPS

djcelery.setup_loader()
CELERYBEAT_SCHEDULER = "djcelery.schedulers.DatabaseScheduler"
BROKER_BACKEND = "djkombu.transport.DatabaseTransport"

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '%(levelname)s %(asctime)s %(name)s %(funcName)s %(lineno)s: %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose'
        },
        'null': {
            'level': 'DEBUG',
            'class': 'django.utils.log.NullHandler',
        },
    },
    'loggers': {
        'django': {
            'handlers': ['null'],
            'propagate': False,
            'level': 'DEBUG',
        },
        'south': {
            'handlers': ['console'],
            'level': 'INFO',
            'propagate': False,
        },
        '': {
            'handlers': ['console'],
            'level': 'DEBUG',
            'propagate': False,
        },
    }
}



#-*- coding:utf8 -*-
import os
import base64
from logan.runner import run_app

KEY_LENGTH = 40

CONFIG_TEMPLATE = """
import os.path

CONF_ROOT = os.path.dirname(__file__)

DATABASES = {
'default': {
# You can swap out the engine for MySQL easily by changing this value
# to ``django.db.backends.mysql`` or to PostgreSQL with
# ``django.db.backends.postgresql_psycopg2``

# If you change this, you'll also need to install the appropriate python
# package: psycopg2 (Postgres) or mysql-python
'ENGINE': 'django.db.backends.sqlite3',

'NAME': os.path.join(CONF_ROOT, 'pingokio.db'),
'USER': 'postgres',
'PASSWORD': '',
'HOST': '',
'PORT': '',

# If you're using Postgres, we recommend turning on autocommit
# 'OPTIONS': {
# 'autocommit': True,
# }
}
}
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'

EMAIL_HOST = 'localhost'
EMAIL_HOST_PASSWORD = ''
EMAIL_HOST_USER = ''
EMAIL_PORT = 25
EMAIL_USE_TLS = False
"""


def generate_settings():
    """
    This command is run when ``default_path`` doesn't exist, or ``init`` is
    run and returns a string representing the default data to put into their
    settings file.
    """
    output = CONFIG_TEMPLATE % dict(
        default_key=base64.b64encode(os.urandom(KEY_LENGTH)),
    )

    return output


def main():
    run_app(
        project='pingokio',
        default_config_path='~/.pingokio/pingokio_settings.py',
        default_settings='pingokio.server.settings',
        settings_initializer=generate_settings,
        settings_envvar='PINGOKIO_CONF',
    )

if __name__ == '__main__':
    main()



from django.conf.urls import patterns, include, url
from django.views.generic.base import RedirectView

from django.contrib import admin
admin.autodiscover()

urlpatterns = patterns(
    '',
    url(r'^$', RedirectView.as_view(url='/admin/'), name='redirecto-to-admin'),
    url(r'^admin/', include(admin.site.urls)),
)



#-*- coding:utf-8 -*-
from django.contrib import admin

from pingokio.domains.models import Domain, AvailabilityTestCase, CheckLog


class AvailabilityTestCaseInline(admin.TabularInline):
    model = AvailabilityTestCase


class DomainAdmin(admin.ModelAdmin):
    inlines = [AvailabilityTestCaseInline]


class CheckLogAdmin(admin.ModelAdmin):
    list_display = ('atc', 'status')


admin.site.register(Domain, DomainAdmin)
admin.site.register(CheckLog, CheckLogAdmin)



from distutils.core import setup
import os
SETUP_PATH = os.path.abspath(os.path.dirname(__file__))


def is_package(path):
    return (os.path.isdir(path) and os.path.isfile(os.path.join(path, '__init__.py')))


def find_packages(path, base=""):
    """ Find all packages in path """
    packages = {}
    for item in os.listdir(path):
        dir = os.path.join(path, item)
        if is_package(dir):
            if base:
                module_name = "%(base)s.%(item)s" % vars()
            else:
                module_name = item
            packages[module_name] = dir
            packages.update(find_packages(dir, module_name))
    return packages


setup(
    name='Pingokio',
    version='0.0.7-pre-alpha3',
    author='Yevgeniy Shchemelev',
    author_email='shchemelevev@gmail.com',
    package_dir={'': 'src'},
    packages=find_packages("src"),
    url='https://github.com/shchemelevev/pingokio',
    license='MIT',
    description='You site uptime statistic collector',
    long_description=open(os.path.join(SETUP_PATH, 'README.md')).read(),
    install_requires=[
        "Django >= 1.5.1",
        "celery >= 3.0.19",
        "django-celery >= 3.0.17",
        "django-kombu >= 0.9.4",
        "logan >= 0.5.6"
    ],
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Topic :: Software Development'
    ],
    entry_points={
        'console_scripts': [
            'pingokio = pingokio.server.logan_runner:main',
        ],
    },
)



#-*- coding:utf-8 -*-
import logging

from django.db import models

logger = logging.getLogger(__name__)


class Domain(models.Model):
    name = models.CharField(max_length=50)

    class Meta:
        verbose_name = u'domain'
        verbose_name_plural = 'domains'

    def __unicode__(self):
        return self.name


class AvailabilityTestCase(models.Model):
    POST = 'PO'
    GET = 'GE'
    PING = 'PI'
    TEST_CASE_KIND_CHOICES = (
        (POST, 'POST'),
        (GET, 'GET'),
        (PING, 'PING')
    )
    domain = models.ForeignKey(Domain)
    kind = models.CharField(max_length=2, choices=TEST_CASE_KIND_CHOICES, default=GET)
    url = models.URLField(max_length=500)
    parameters = models.TextField(max_length=600, null=True, blank=True)
    period = models.IntegerField(u'Interval in seconds', default=15)

    def __unicode__(self):
        return '{0} {1}'.format(self.domain, self.kind)


class CheckLog(models.Model):
    atc = models.ForeignKey(AvailabilityTestCase)
    result = models.TextField(max_length=1000, null=True, blank=True)
    status = models.BooleanField(null=False, blank=False, default=True)
    created = models.DateTimeField(auto_now_add=True)
